from data.Frame import Frame
from geo.countries import Countries

# This function returns a dataframe with countries passed as an array (g) using the field specific in (column_name)
def extract_countries(g, column_name, df):
    n_df = Frame()
    c = Countries()
    
    names = []

    for ctr_name in g:
        ctr = c.get_country_by_name(ctr_name)
        names.append(ctr.name)

        for i in ctr.alias:
            names.append(i)

    for r in df.rows:          
        if (r.get_by_column_name(column_name).value.value in names):
            n_df.rows.append(r)
    
    return(n_df)


import sys
import os
sys.path.append(os.getcwd().split("geo")[0])
from paises.country import Country
from texttable import Texttable
from paises.cache import *

from paises.data import ldcs2025, ldcs2019, ldcs2018, ldcs2017, lldcs, mics, mics_lower, \
	mics_upper, oecd, sids, africa, asia, \
	america, north_america, central_america, south_america, \
	europe, oecd, pacific_islands, asia_and_the_pacific, \
	developing_excluding_ldcs, \
	country_alias

cache_folder = os.getcwd().split('geo')[0] + 'datascrapper2/countries/cache'

class Countries(list):

	def __init__(self):
		if len(self) == 0:
			pass

	def __iter__(self):
		self.idx = 0
		return self

	def __next__(self):
		if self.idx < len(self):
			self.idx += 1
			return self[self.idx - 1]
		else:
			raise StopIteration

	# prints the dataframe
	def print(self, **kwargs):		
		table = Texttable()

		for r in self:
			table.add_row(r.as_array())
		table_s = table.draw()

	#def __repr__(self):
		# table = Texttable()

		#for r in self:
		#	table.add_row(r.as_array())
		
		#table_s = table.draw()

		#return str(table_s)
	#	yield

	# Get a country object using the name
	def get(self, n):
		for c in self:
			if n == c.name or n in c.alias:
				return c
		return None

	# Return countries belonging to a group
	def get_group(self, g):		
		ctrs = Countries()	
		if (isinstance(g, str)):
			for c in self:
				for group in c.groups:	
					if group == g: 										
						ctrs.append(c)
		else:
			for c in self:
				if set(g).issubset(c.groups):				
					ctrs.append(c)

		return ctrs


	# Return this list as ISO2
	def get_as_iso2(self):
		iso2_list = []
		for c in self:
			iso2_list.append(c.iso2code)
		return iso2_list

	# Return this list as ISO3
	def get_as_iso3(self):
		iso3_list = []
		for country in countries:
			if (self.get_iso3_from_country_name(country) != None):
				iso3_list.append(self.get_iso3_from_country_name(country))
		return iso3_list

	# Return this lsit as fao code
	def get_as_fao_code(self):
		fao_code_list = []
		for country in self:
			fao_code_list.append(country.fao_code)	
		return fao_code_list		

	# Return the name of a country using the iso2 code
	def get_name_from_iso2(self, iso2code):
		for c in self:
			if c.iso2code == iso2code:
				return c.name
	
	# Return the name of a country using the iso3 code
	def get_name_from_iso3(self, iso3code):
		for c in self:
			if c.iso3code == iso3code:
				return c.name

	# Add the corresponding group to each country in items
	def add_group(self, group, items):
		for c in self:
			if c.name in items:
				c.groups.append(groups)

	# Return an array with country names on this list
	def get_names(self):

		names = []
		for c in self:
			names.append(c.name)
			
		return(names)

	# Return the list of names and aliases
	def get_names_and_aliases(self):
		names = []
		for c in self:
			names.append(c.name)
			for i in c.alias:
				names.append(i)
		return(names)

	# Add group information to country in list
	# based on data stored in lists
	def get_country_groups(self, country):

		groups = []

		if country in ldcs2025:
			groups.append("LDCs2025")

		if country in ldcs2019:
			groups.append("LDCs2019")

		if country in ldcs2018:
			groups.append("LDCs")

		if country in ldcs2017:
			groups.append("LDCs2017")
		
		if country in lldcs:
			groups.append("LLDCs")

		if country in mics:
			groups.append("MICs")

		if country in mics_lower:
			groups.append("LMICs")

		if country in mics_upper:
			groups.append("UMICs")

		if country in oecd:
			groups.append("OECD")

		if country in sids:
			groups.append("SIDS")

		if country in pacific_islands:
			groups.append("Pacific islands")

		if country in asia_and_the_pacific:
			groups.append("Asia and the Pacific")

		if country in africa:
			groups.append("Africa")

		if country in asia:
			groups.append("Asia")

		if country in america:
			groups.append("America")

		if country in developing_excluding_ldcs:
			groups.append("Developing excluding LDCs")

		return groups

	# Check if a country belongs to a group

	def is_in_group(self, name):
		for c in self:
			if c.name == name or name in c.groups:
				return True
		return False

	# Check if a country belongs to a region
	def is_in_region(self, name):

		if name in africa:
			return "Africa"

		if name in asia:
			return "Asia"

		if name in north_america:
			return "North America"

		if name in central_america:
			return "Central America"

		if name in south_america:
			return "South America"

		if name in europe:
			return "Europe"

	# Get a list of country names that is in the specified groups
	def get_country_names_from_groups(self, groups):
		ctrs = self.get_countries_in_group(groups)
		country_names = []
		for ctr in ctrs:
			if ctr.name not in country_names:
				country_names.append(ctr.name)
		
		return country_names

	# Return country names on this list as json
	def as_json(self):
		ctrs = {}
		for w in self:
			ctrs[w.name] = w.as_json()

		return ctrs
	
	
	# Set an alias for a country

	def set_country_alias(self, c, a):
		for ctry in self:
			if ctry.name == c:
				ctry.alias = a

	# load aliases for countries

	def load_country_alias(self):
		for k in country_alias:
			self.set_country_alias(k,country_alias[k])
	
	# Load country data from the worldbank
	# We fetch data from the World Bank
	# We use a cache system
	def load_wb(self):
		
		file_name = 'countries'
		p = get_file_path(file_name)
		if check_cache(p) == False:
			retrieve_and_cache(name=file_name)	
		else:
			check_age(file_name)    	
		
		cached_data = load_cache(p)
		
		# Store data in array
		for item in cached_data[1]:
			c = Country()
			c.name = item['name']
			c.iso2code = item['iso2Code']
			c.capitalcity = item['capitalCity']
			c.iso3code = item['id']
			c.incomelevel = item['incomeLevel']['value']
			c.capital_longitude = item['longitude']
			c.capital_latitude = item['latitude']
			c.lendingtype = item['lendingType']['value']
			c.groups = self.get_country_groups(c.name)
			c.region = self.is_in_region(c.name)
			self.append(c)

		# Now we add aliases of countries
		self.load_country_alias()

	# Load the codes used by the FAO
	def load_fao_code(self):
		fao_countries = sources.fao.data.load_countries()
		for ctr in self:			
			if (fao_countries.search('label', ctr.name).count() > 0):
				f_c = fao_countries.search('label', ctr.name).rows[0].get_cell('code').get_value()
				ctr.fao_code = f_c
			else:
				for al in ctr.alias:
					if (fao_countries.search('label', al).count() > 0):
						f_c = fao_countries.search('label', al).rows[0].get_cell('code').get_value()
						ctr.fao_code = f_c	
				

	# Load the codes use by the FAO
	def load_sdg_code(self):
		areas = sources.sdgs.areas.load_areas()
		for a in areas:
			if (self.get_cell(a.get_cell('geoAreaName').get_value()) is not None):
				self.get_cell(a.get_cell('geoAreaName').get_value()).sdg_code = str(a.get_cell('geoAreaCode').get_value()).split(".")[0]



class Country:
    name = ''
    aliases = []
    iso2code = ''
    capital = ''
    iso3code = ''
    incomelevel = ''
    capital_longitude = ''
    capital_latitude = ''
    lendingtype = ''
    region = ''
    groups = []
    alias = []
    fao_code = ''
    sdg_code = ''

    def __getitem__(self,key):
        return getattr(self,key)

    #def __repr__(self):
        #return ("****************************\nName: %s\nAliases: %s\n CapitaL %s Iso2code: %s Iso3code: %s Income level: %s Longitude (capital): %s Latitude (capital): %s Lending type: %s-%s\n%s\n%s\n%s\n%s\n" % (self.name, self.aliases, self.iso2code, self.capital, self.iso3code, self.incomelevel, self.capital_longitude, self.capital_latitude, self.lendingtype, self.region, str(self.groups), str(self.alias), self.fao_code, self.sdg_code))

    def as_json(self):
    	# The replacement of (.) is done to avoid issues with key in mongodb
        return dict(name=self.name.replace(".", ""), aliases=self.aliases, iso2code=self.iso2code, capitalcity=self.capitalcity, iso3code=self.iso3code, incomelevel=self.incomelevel, capital_longitude=self.capital_longitude, capital_latitude=self.capital_latitude, lendingtype=self.lendingtype, region=self.region, groups=self.groups)
    
    def as_array(self):
        return([self.name, str(self.aliases), self.iso2code, self.capital, self.iso3code, self.incomelevel, str(self.capital_longitude), str(self.capital_latitude), self.lendingtype, self.region, str(self.groups), str(self.alias), self.fao_code, self.sdg_code])



# -*- coding: utf-8 -*-
from paises.country import Country
from paises.ccs import *

List = []

country_alias = {
    'Bahamas, The': ['Bahamas'],
    'Bolivia':['Bolivia (Plurinational State of)'],
    'Central African Republic': ['CAR'],
    'Congo, Dem. Rep.': ['Democratic Republic of the Congo', 'DR Congo', 'DRC', 'D.R. of the Congo'],
    'Congo': ['Republic of Congo'],
    'Gambia, The': ['Gambia', 'The Gambia', 'Gambia (Republic of The)'],
    'Guinea-Bissau': ['Guinea Bissau'],
    'Iran, Islamic Rep.':['Iran', 'Iran (Islamic Republic of)', 'Islamic Republic of Iran'],
    'Lao PDR': ["Lao People's Democratic Republic", 'Laos', 'Lao P.D.R.', "Lao People's DR"],
    'Micronesia, Fed. Sts.': ['Micronesia (Federated States of)'],
    'St. Vincent and the Grenadines':  ['Saint Vincent and the Grenadines'],
    'St. Kitts and Nevis': ['Saint Kitts and Nevis '],
    'St. Lucia': ['Saint Lucia'],
    'Sao Tome and Principe':["São Tomé and Príncipe", "SÃ£o TomÃ© and PrÃ­ncipe", "São Tomé and Principe"],
    'Syria': ['Syrian Arab Republic'],
    'Tanzania': ['United Republic of Tanzania', 'U.R. of Tanzania: Mainland'],
    'United Kingdom': ['United Kingdom of Great Britain and Northern Ireland'],
    'United States': ['United States of America'],
    'Venezuela': ['Venezuela, RB', 'Venezuela, Bolivarian Republic of', 'Venezuela (Bolivarian Republic of)', 'Venezuela(Bolivarian Republic of)'],
    'Vietnam': ['Viet Nam'],
    'Yemen, Rep.': ['Yemen'],
    "Egypt": ['Egypt, Arab Rep.'],
    "Korea, Dem. People's Rep.": ["Democratic People's Republic of Korea ", 'North Korea'],
    }

ldcs2025 = {
    'Angola', 'Benin', 'Burkina Faso', 'Burundi',
    'Central African Republic', 'Chad', 'Comoros',
    'Congo, Dem. Rep.', 'Djibouti',
    'Eritrea', 'Ethiopia', 'Gambia, The', 'Guinea',
    'Guinea-Bissau', 'Lesotho', 'Liberia', 'Madagascar',
    'Malawi', 'Mali', 'Mauritania', 'Mozambique',
    'Niger', 'Rwanda',
    'Senegal', 'Sierra Leone', 'Somalia', 'South Sudan',
    'Sudan', 'Togo', 'Tanzania', 'Uganda',
    'Zambia', 'Afghanistan', 'Cambodia', 'Kiribati', 'Lao PDR',
    'Myanmar', 'Nepal', 'Tuvalu', "Timor-Leste", 'Vanuatu',
    'Yemen, Rep.', 'Haiti'
}

ldcs2019 = [
    'Angola', 'Benin', 'Burkina Faso', 'Burundi',
    'Central African Republic', 'Chad', 'Comoros',
    'Congo, Dem. Rep.', 'Djibouti',
    'Eritrea', 'Ethiopia', 'Gambia, The', 'Guinea',
    'Guinea-Bissau', 'Lesotho', 'Liberia', 'Madagascar',
    'Malawi', 'Mali', 'Mauritania', 'Mozambique',
    'Niger', 'Rwanda', 'Sao Tome and Principe',
    'Senegal', 'Sierra Leone', 'Somalia', 'South Sudan',
    'Sudan', 'Togo', 'Tanzania', 'Uganda',
    'Zambia', 'Afghanistan', 'Bangladesh',
    'Bhutan', 'Cambodia', 'Kiribati', 'Lao PDR',
    'Myanmar', 'Nepal', 'Solomon Islands',
    'Tuvalu', "Timor-Leste", 'Vanuatu', 'Yemen, Rep.', 'Haiti']

ldcs2018 = [
    'Angola', 'Benin', 'Burkina Faso', 'Burundi',
    'Central African Republic', 'Chad', 'Comoros',
    'Congo, Dem. Rep.', 'Djibouti',
    'Eritrea', 'Ethiopia', 'Gambia, The', 'Guinea',
    'Guinea-Bissau', 'Lesotho', 'Liberia', 'Madagascar',
    'Malawi', 'Mali', 'Mauritania', 'Mozambique',
    'Niger', 'Rwanda', 'Sao Tome and Principe',
    'Senegal', 'Sierra Leone', 'Somalia', 'South Sudan',
    'Sudan', 'Togo', 'Tanzania', 'Uganda',
    'Zambia', 'Afghanistan', 'Bangladesh',
    'Bhutan', 'Cambodia', 'Kiribati', 'Lao PDR',
    'Myanmar', 'Nepal', 'Solomon Islands',
    'Tuvalu', "Timor-Leste", 'Vanuatu', 'Yemen, Rep.', 'Haiti']

ldcs2017 = [
    'Angola', 'Benin', 'Burkina Faso', 'Burundi',
    'Central African Republic', 'Chad', 'Comoros',
    'Congo, Dem. Rep.', 'Djibouti', 'Equatorial Guinea',
    'Eritrea', 'Ethiopia', 'Gambia, The', 'Guinea',
    'Guinea-Bissau', 'Lesotho', 'Liberia', 'Madagascar',
    'Malawi', 'Mali', 'Mauritania', 'Mozambique',
    'Niger', 'Rwanda', 'Sao Tome and Principe',
    'Senegal', 'Sierra Leone', 'Somalia', 'South Sudan',
    'Sudan', 'Togo', 'Tanzania', 'Uganda',
    'Zambia', 'Afghanistan', 'Bangladesh',
    'Bhutan', 'Cambodia', 'Kiribati', 'Lao PDR',
    'Myanmar', 'Nepal', 'Solomon Islands',
    'Tuvalu', "Timor-Leste", 'Vanuatu', 'Yemen, Rep.', 'Haiti']

# LLDCs

lldcs = [
    'Botswana', 'Burkina Faso', 'Burundi',
    'Central African Republic',
    'Chad', 'Ethiopia', 'Lesotho',
    'Malawi', 'Mali', 'Niger', 'Rwanda', 'South Sudan',
    'Eswatini', 'Uganda', 'Zambia',
    'Zimbabwe', 'Afghanistan', 'Bhutan',
    'Kazakhstan', 'Kyrgyz Republic', 'Lao PDR',
    'Mongolia', 'Nepal', 'Tajikistan', 'Turkmenistan',
    'Uzbekistan', 'Armenia', 'Azerbaijan', 'Moldova',
    'North Macedonia', 'Bolivia', 'Paraguay']

# SIDS

sids = [
    'Antigua and Barbuda', 'Bahamas', 'Bahrain', 'Barbados', 'Belize',
    'Cape Verde', 'Comoros', 'Cuba', 'Dominica', 'Dominican Republic',
    'Fiji', 'Grenada', 'Guinea-Bissau', 'Guyana', 'Haiti', 'Jamaica',
    'Kiribati', 'Maldives', 'Marshall Islands',
    'Federated States of Micronesia', 'Mauritius', 'Nauru', 'Palau',
    'Papua New Guinea', 'Samoa', 'Sao Tome and Principe', 'Singapore',
    'St Kitts and Nevis',
    'St Lucia', 'St Vincent and the Grenadines', 'Seychelles',
    'Solomon Islands', 'Suriname', 'Timor-Leste', 'Tonga',
    'Trindad and Tobago', 'Tuvalu', 'Vanuatu', 'American Samoa',
    'Anguilla', 'Aruba', 'British Virgin Islands',
    'Commonwealth of Northern Marianas', 'Cook Islands',
    'French Polynesia', 'Guam', 'Montserrat', 'Netherlands Antilles',
    'New Caledonia', 'Niue', 'Puerto Rico', 'US Virgin Islands']

# this is the list of middle income List following the criteria of
# the World Bank, but excluding the LDCs in the Lower Middle-Income
# category

mics_lower = [
    'Albania', 'Indonesia', 'Armenia', 'India', 'Belize', 'Iraq',
    'Bolivia', 'Kosovo', 'Cameroon', 'Sri Lanka', 'Cape Verde',
    ' Rep Marshall Islands', 'Swaziland', 'Cote d\'Ivoire',
    'Micronesia, Fed Sts', 'Syrian Arab Republic', 'Moldova', 'Egypt',
    'Arab Rep', 'Mongolia', 'Tonga', 'El Salvador', 'Morocco', 'Ukraine',
    'Fiji', 'Nicaragua', 'Uzbekistan', 'Georgia', 'Nigeria', 'Ghana',
    'Pakistan', 'Vietnam', 'Guatemala', 'Papua New Guinea',
    'West Bank and Gaza', 'Guyana', 'Paraguay', 'Honduras', 'Philippines']

mics_upper = [
    'Ecuador', 'Palau', 'Algeria', 'Gabon', 'Panama', 'American Samoa',
    'Grenada', 'Peru',  'Antigua and Barbuda', 'Iran, Islamic Rep',
    'Romania', 'Argentina', 'Jamaica', 'Russian Federation',
    'Azerbaijan', 'Jordan', 'Serbia', 'Belarus', 'Kazakhstan',
    'Seychelles', 'Bosnia and Herzegovina', 'Latvia', 'South Africa',
    'Botswana', 'Lebanon', 'St Lucia', 'Brazil', 'Libya', 'St Vincent and the Grenadines',
    'Bulgaria', 'Lithuania', 'Suriname', 'Chile', 'Macedonia, FYR',
    'Thailand', 'China', 'Malaysia', 'Tunisia', 'Colombia',
    'Maldives', 'Turkey', 'Costa Rica', 'Mauritius',
    'Turkmenistan', 'Cuba', 'Mexico', 'Dominica', 'Montenegro',
    'Uruguay', 'Dominican Republic', 'Namibia', 'Venezuela, RB']

mics = mics_lower + mics_upper

# OECD List
oecd = [
    'Australia', 'Austria', 'Belgium', 'Canada', 'Chile', 'Czech Republic',
    'Denmark', 'Estonia', 'Finland', 'France', 'Germany', 'Greece',
    'Hungary', 'Iceland', 'Ireland', 'Israel', 'Italy', 'Japan',
    'Korea, Rep.', 'Latvia', 'Luxembourg', 'Mexico', 'Netherlands', 'New Zealand',
    'Norway', 'Poland', 'Portugal', 'Slovak Republic', 'Slovenia', 'Spain',
    'Sweden', 'Switzerland', 'Turkey', 'United Kingdom', 'United States']

# Developed List

developed = [
    'Andorra', 'Australia', 'Austria', 'Belgium', 'Bulgaria', 'Bermuda',
    'Canada', 'Cyprus', 'Chile', 'Czech Republic', 'Denmark', 'Estonia',
    'Faeroe Islands', 'Finland', 'France', 'Germany', 'Gibraltar', 'Greece',
    'Holy See', 'Hungary', 'Iceland', 'Ireland', 'Israel',
    'Italy', 'Japan', 'Lithuania', 'Korea, Rep.', 'Luxembourg', 'Malta',
    'Mexico', 'Netherlands', 'New Zealand', 'Norway', 'Poland', 'Portugal',
    'Romania', 'San Marino', 'Slovak Republic', 'Slovenia', 'Spain', 'Sweden',
    'Switzerland', 'Turkey', 'Latvia', 'United Kingdom', 'United States']

# Developing
# According to UNSD classification available at:
# https://unstats.un.org/unsd/methodology/m49/

developing_unsd = [
'Afghanistan','Algeria','American Samoa','Angola','Anguilla',
'Antigua and Barbuda', 'Argentina','Armenia','Aruba','Azerbaijan','Bahamas',
'Bahrain','Bangladesh', 'Barbados', 'Belize','Benin','Bhutan',
'Bolivia (Plurinational State of)', 'Bonaire, Sint Eustatius and Saba',
'Botswana','Brazil','British Indian OceanTerritory','British Virgin Islands','Brunei Darussalam',
'Burkina Faso','Burundi','Cabo Verde','Cambodia','Cameroon','Cayman Islands','Central African Republic',
'Chad','Chile','China','China, Hong Kong Special Administrative Region',
'China, Macao Special Administrative Region',
'Colombia','Comoros','Congo','Cook Islands', 'Costa Rica','C&#244;te d&#39;Ivoire' ,'Cuba',
'Cura&#231;ao', 'Cyprus', 'Democratic People&#39;s Republic of Korea',
'Democratic Republic of the Congo','Djibouti','Dominica','Dominican Republic',
'Ecuador','Egypt','El Salvador','Equatorial Guinea','Eritrea','Ethiopia',
'Falkland Islands (Malvinas)','Fiji','French Guiana','French Polynesia',
'French Southern Territories','Gabon','Gambia','Georgia',
'Ghana','Grenada','Guadeloupe','Guam','Guatemala','Guinea','Guinea-Bissau',
'Guyana','Haiti','Honduras','India','Indonesia', 'Iran (Islamic Republic of)',
'Iraq','Israel','Jamaica','Jordan','Kazakhstan','Kenya','Kiribati','Kuwait',
'Kyrgyzstan','Lao People&#39;s Democratic Republic','Lebanon','Lesotho',
'Liberia','Libya','Madagascar','Malawi','Malaysia','Maldives','Mali','Marshall Islands',
'Martinique','Mauritania','Mauritius','Mayotte','Mexico',
'Micronesia (Federated States of)','Mongolia','Montserrat','Morocco',
'Mozambique','Myanmar','Namibia','Nauru','Nepal','New Caledonia',
'Nicaragua','Niger','Nigeria','Niue','Northern Mariana Islands',
'Oman','Pakistan','Palau','Panama','Papua New Guinea','Paraguay','Peru',
'Philippines','Pitcairn','Puerto Rico','Qatar','Republic of Korea','R&#233;union',
'Rwanda','Saint Barth&#233;lemy','Saint Helena','Saint Kitts and Nevis','Saint Lucia',
'Saint Martin (French Part)','Saint Vincent and the Grenadines','Samoa',
'Sao Tome and Principe','Saudi Arabia','Senegal','Seychelles','Sierra Leone',
'Singapore','Sint Maarten (Dutchpart)','Solomon Islands','Somalia','South Africa',
'South Georgia and the South Sandwich Islands','South Sudan','Sri Lanka',
'State of Palestine','Sudan','Suriname','Swaziland','Syria',
'Tajikistan','Thailand','Timor-Leste','Togo','Tokelau','Tonga',
'Trinidad and Tobago','Tunisia','Turkey','Turkmenistan','Turks and Caicos Islands',
'Tuvalu','Uganda','United Arab Emirates','United Republic of Tanzania',
'United States Minor Outlying Islands','United States Virgin Islands','Uruguay',
'Uzbekistan','Vanuatu','Venezuela (Bolivarian Republic of)','Viet Nam',
'Wallis and Futuna Islands','Western Sahara','Yemen, Rep.','Zambia','Zimbabwe'
]

# List of developing economies excludiong LDCs as used by UNCTAD
# for analytical purposes
# http://unctadstat.unctad.org/EN/Classifications.html

developing_excluding_ldcs = [
    'Algeria',
    'American Samoa',
    'Anguilla',
    'Antigua and Barbuda',
    'Argentina',
    'Armenia',
    'Aruba',
    'Azerbaijan',
    'Bahamas',
    'Bahrain',
    'Barbados',
    'Belize',
    'Bolivia',
    'Bonaire, Sint Eustatius and Saba',
    'Botswana',
    'Brazil',
    'British Indian OceanTerritory',
    'British Virgin Islands',
    'Brunei Darussalam',
    'Cabo Verde',
    'Cameroon',
    'Cayman Islands',
    'Chile',
    'China',
    'China, Hong Kong Special Administrative Region',
    'China, Macao Special Administrative Region',
    'Colombia',
    'Republic of Congo',
    'Cook Islands',
    'Costa Rica',
    'C&#244;te d&#39;Ivoire' ,
    'Cuba',
    'Cura&#231;ao',
    'Cyprus',
    'Democratic People&#39;s Republic of Korea',
    'Dominica',
    'Dominican Republic',
    'Ecuador',
    'Equatorial Guinea',
    'Egypt',
    'El Salvador',
    'Falkland Islands (Malvinas)',
    'Fiji',
    'French Guiana',
    'French Polynesia',
    'French Southern Territories',
    'Gabon',
    'Georgia',
    'Ghana',
    'Grenada',
    'Guadeloupe',
    'Guam',
    'Guatemala',
    'Guyana',
    'Honduras',
    'India',
    'Indonesia',
    'Iran',
    'Iraq',
    'Israel',
    'Jamaica',
    'Jordan',
    'Kazakhstan',
    'Kenya',
    'Kuwait',
    'Kyrgyzstan',
    'Lebanon',
    'Libya',
    'Malaysia',
    'Maldives',
    'Martinique',
    'Mauritius',
    'Mayotte',
    'Mexico',
    'Micronesia (Federated States of)',
    'Mongolia',
    'Montserrat',
    'Morocco',
    'Namibia',
    'Nauru',
    'New Caledonia',
    'Nicaragua',
    'Nigeria',
    'Niue',
    'Northern Mariana Islands',
    'Oman',
    'Pakistan',
    'Palau',
    'Panama',
    'Papua New Guinea',
    'Paraguay',
    'Peru',
    'Philippines',
    'Pitcairn',
    'Puerto Rico',
    'Qatar',
    'Republic of Korea',
    'R&#233;union',
    'Saint Barth&#233;lemy',
    'Saint Helena',
    'Saint Kitts and Nevis',
    'Saint Lucia',
    'Saint Martin (French Part)',
    'Saint Vincent and the Grenadines',
    'Saudi Arabia',
    'Senegal',
    'Seychelles',
    'Singapore',
    'Sint Maarten (Dutchpart)',
    'South Africa',
    'South Georgia and the South Sandwich Islands',
    'Sri Lanka',
    'State of Palestine',
    'Suriname',
    'Swaziland',
    'Syria',
    'Tajikistan',
    'Thailand',
    'Tokelau',
    'Tonga',
    'Trinidad and Tobago',
    'Tunisia',
    'Turkey',
    'Turkmenistan',
    'Turks and Caicos Islands',
    'United Arab Emirates',
    'United States Minor Outlying Islands',
    'United States Virgin Islands',
    'Uruguay',
    'Uzbekistan',
    'Venezuela (Bolivarian Republic of)',
    'Viet Nam',
    'Wallis and Futuna Islands',
    'Western Sahara',
    'Zimbabwe'
]

africa = [
    'Algeria', 'Angola', 'Benin', 'Botswana',
    'Burkina Faso', 'Burundi', 'Cameroon', 'Cape Verde',
    'Central African Republic', 'Chad', 'Comoros', 'Congo, Dem. Rep.',
    'Republic of Congo', 'Cote d\'Ivoire', 'Djibouti', 'Egypt',
    'Equatorial Guinea', 'Eritrea', 'Ethiopia', 'Gabon', 'Gambia, The',
    'Ghana', 'Guinea', 'Guinea-Bissau', 'Kenya',
    'Lesotho', 'Liberia', 'Libya', 'Madagascar', 'Malawi', 'Mali',
    'Mauritania', 'Mauritius', 'Morocco', 'Mozambique', 'Namibia',
    'Niger', 'Nigeria', 'Rwanda', 'Saint Helena', 'Sao Tome and Principe',
    'Senegal', 'Seychelles', 'Sierra Leone', 'Somalia', 'Somaliland', 'South Africa',
    'South Sudan', 'Sudan', 'Swaziland', 'Tanzania', 'Togo', 'Tunisia',
    'Uganda', 'Western Sahara', 'Zambia', 'Zimbabwe', 'British Indian Ocean Territory']

eastern_africa = [
    'Burundi', 'Comoros', 'Djibouti', 'Eritrea', 'Ethiopia', 'Kenya',
    'Madagascar', 'Malawi', 'Mauritius', 'Mayotte', 'Mozambique',
    'Réunion', 'Rwanda', 'Seychelles', 'Somalia', 'South Sudan',
    'Uganda', 'United Republic of Tanzania', 'Zambia', 'Zimbabwe'
]

middle_africa = [
    'Angola', 'Cameroon', 'Central African Republic',
    'Democratic Republic of the Congo', 'Equatorial Guinea',
    'Gabon', 'Sao Tome and Principe'
]

northern_africa = [
    'Algeria', 'Egypt', 'Libya', 'Morocco', 'Sudan', 'Tunisia',
    'Western Sahara'
]

southern_africa = [
    'Botswana', 'Lesotho', 'Namibia', 'South Africa', 'Swaziland'
]

western_africa = [
    'Benin', 'Burkina Faso', 'Cabo Verde', 'Cote d\'Ivoire',
    'Gambia', 'Ghana', 'Guinea', 'Guinea-Bissau', 'Liberia',
    'Mali', 'Mauritania', 'Niger', 'Nigeria', 'Saint Elena',
    'Senegal', 'Sierra Leone', 'Togo'
]

asia = [
    'Palestine', 'Afghanistan', 'Bahrain', 'Bangladesh', 'Bhutan',
    'Brunei Darussalam', 'Myanmar', 'Cambodia', 'China', 'India',
    'Indonesia', 'Iran', 'Iraq', 'Israel', 'Japan', 'Jordan',
    'Kazakhstan', 'North Korea', 'South Korea', 'Kuwait', 'Kyrgyzstan',
    'Lao PDR', 'Lebanon',
    'Malaysia', 'Maldives', 'Mongolia', 'Nepal', 'Oman', 'Pakistan',
    'Philippines', 'Qatar', 'Saudi Arabia', 'Singapore', 'Sri Lanka',
    'Syria', 'Taiwan', 'Tajikistan', 'Thailand', 'Timor-Leste',
    'Turkmenistan', 'United Arab Emirates', 'Uzbekistan', 'Vietnam',
    'Yemen, Rep.', 'Hong Kong', 'Macau']

pacific_islands = [
    'Fiji', 'Kiribati', 'Marshall Islands',
    'Micronesia, Federated States of', 'Nauru', 'Palau',
    'Samoa', 'Solomon Islands', 'Tonga', 'Tuvalu', 'Vanuatu'
    ]

asia_and_the_pacific = asia + pacific_islands

central_asia = [
    'Kazakhstan', 'Kyrgyzstan', 'Tajikistan', 'Uzbekistan'
]

eastern_asia = [
    'China', 'China, Hong Kong Special Administrative Region',
    'China, Macao Special Administrative Region',
    'Democratic People\'s Republic of Korea',
    'Japan', 'Mongolia', 'Republic of Korea'
]

south_east_asia = [
    'Brunei Darussalam', 'Cambodia', 'Indonesia', 'Laos', 'Malaysia',
    'Myanmar', 'Philippines', 'Singapore', 'Thailand', 'Timor-Leste',
    'Vietnam'
]

western_asia = [
    'Armenia', 'Azerbaijan', 'Bahrain', 'Cyprus', 'Georgia', 'Iraq',
    'Israel', 'Jordan', 'Kuwait', 'Lebanon', 'Oman', 'Qatar',
    'Saudi Arabia', 'State of Palestine', 'Syria', 'Turkey',
    'United Arab Emirates', 'Yemen, Rep.'
]

caribbean = [
    'Anguilla', 'Antigua and Barbuda', 'Aruba', 'Bahamas', 'Barbados',
    'Bonaire, Sint Eustatius and Saba', 'British Virgin Islands',
    'Cayman Islands', 'Cuba', 'Curaçao', 'Dominica', 'Dominican Republic',
    'Grenada', 'Guadeloupe', 'Haiti', 'Jamaica', 'Martinique', 'Montserrat',
    'Puerto Rico', 'Saint-Barthélemi', 'Sanit Kitts and Nevis', 'Saint Lucia',
    'Saint Martin', 'Saint Vincent and the Grenadines', 'Sint Marteen',
    'Trinidad and Tobago', 'Turks and Caicos Islands', 'United States Virgin Islands'
]

central_america = [
    'Belize', 'Costa Rica', 'El Salvador', 'Guatemala', 'Honduras', 'Mexico',
    'Nicaragua', 'Panama'
]

north_america = [
    'Saint Martin', 'Anguilla', 'Antigua and Barbuda', 'Aruba', 'Bahamas',
    'Barbados', 'Bermuda', 'British Virgin Islands', 'Cayman Islands',
    'Cuba', 'Curacao', 'Dominica', 'Dominican Republic',
    'Grenada', 'Haiti', 'Jamaica', 'Montserrat', 'Puerto Rico',
    'Saint Barthelemy', 'Saint Kitts and Nevis', 'Saint Lucia', 'Sint Maarten',
    'Trinidad and Tobago', 'Turks and Caicos Islands', 'US Virgin Islands', 'United States']

south_america = [
    'Argentina', 'Bolivia', 'Brazil', 'Chile', 'Colombia', 'Ecuador',
    'Falkland Islands', 'Guyana', 'Paraguay', 'Peru', 'Suriname', 'Uruguay',
    'Venezuela']

america = central_america + north_america  + south_america


europe = [
    'Aland Islands', 'Albania', 'Andorra', 'Armenia', 'Austria', 'Azerbaijan',
    'Belarus', 'Belgium', 'Bosnia and Herzegovina', 'Bulgaria', 'Croatia',
    'Cyprus', 'Czech Republic', 'Denmark', 'Estonia', 'Faroe Islands',
    'Finland', 'France', 'Georgia', 'Germany', 'Gibraltar', 'Greece',
    'Guernsey', 'Vatican City', 'Hungary', 'Iceland', 'Ireland',
    'Isle of Man',
    'Italy', 'Jersey', 'Kosovo', 'Latvia', 'Liechtenstein', 'Lithuania',
    'Luxembourg', 'Macedonia', 'Malta', 'Moldova', 'Monaco', 'Montenegro',
    'Netherlands', 'Norway', 'Poland', 'Portugal', 'Romania', 'Russia',
    'San Marino', 'Serbia', 'Slovakia', 'Slovenia', 'Spain', 'Svalbard',
    'Sweden', 'Switzerland', 'Turkey', 'Ukraine', 'United Kingdom',
    'Northern Cyprus']

eastern_europe = [
    'Belarus', 'Bulgaria', 'Czech Republic', 'Hungary', 'Poland',
    'Republic of Moldova', 'Romania', 'Russian Federation', 'Slovakia',
    'Ukraine'
    ]

northern_europe = [
    'Åland Islands', 'Channel Islands', 'Denmark', 'Estonia', 'Feroe Islands',
    'Finland', 'Guernsey', 'Iceland', 'Ireland', 'Isle of Man', 'Jersey',
    'Latvia', 'Lithuania', 'Norway', 'Sark', 'Svalbard and Jan Mayen Islands',
    'United Kingdom'
]

southern_europe = [
    'Albania', 'Andorra', 'Bosnia and Herzegovina', 'Croatia', 'Gibraltar',
    'Greece', 'Holy See', 'Italy', 'Malta', 'Montenegro', 'Portugal', 'San Marino',
    'Serbia', 'Slovenia', 'Spain', 'The former Yugoslav Republic of Macedonia'
]

western_europe = [
    'Austria', 'Belgium', 'France', 'Germany', 'Liechtenstein', 'Luxembourg',
    'Monaco', 'Netherlands', 'Switzerland'
]

central_america = [
    'Belize', 'Canada', 'Costa Rica', 'El Salvador', 'Greenland',
    'Guatemala', 'Honduras',
    'Mexico', 'Nicaragua', 'Panama', 'Saint Pierre and Miquelon',
    'Saint Vincent and the Grenadines']

antarctica = ['South Georgia and South Sandwich Islands',
              'French Southern and Antarctic Lands', 'Antarctica',
              'Heard Island and McDonald Islands']

world = europe + asia_and_the_pacific + america + antarctica + africa



from urllib import request
import json
import json
import os
import os.path
import time

#cache_folder = os.getcwd().split('paises')[0] + 'paises/cache'
cache_folder = 'paises/cache'
# 604800 is on week
max_age = 604800

def get_file_path(name):
    return str(cache_folder) + '/' + str(name) + '.json'
        
def check_age(name):
    if (os.path.getmtime(get_file_path(name)) - time.time()) < -max_age:
        print("Updating " + str(name) + " from server.")
        retrieve_and_cache(name)

def check_cache(name):
    return (os.path.exists(name))

def write_cache(data, file_path):
    with open(file_path, 'w') as outfile:
        json.dump(data, outfile)
        outfile.close()
        
def load_cache(file_path):
    with open(file_path) as json_file:
        data = json.load(json_file)
        return (data)

def retrieve_and_cache(name):
    
    # Load country data from the worldbank
    # We fetch data from the World Bank
    url = "http://api.worldbank.org/v2/countries?format=json&per_page=304"
    response = request.urlopen(url)
    codec = response.info().get_param('charset', 'utf8')
    data = json.loads(response.read().decode(codec))

    f = get_file_path(name)
    write_cache(data, f)
    print("Files updated from server")

		


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['paises']

package_data = \
{'': ['*'], 'paises': ['cache/*', 'cache/backup/*', 'cache/groups/*']}

install_requires = \
['importlib>=1.0.4,<2.0.0', 'pytest>=7.1.3,<8.0.0', 'texttable>=1.6.4,<2.0.0']

setup_kwargs = {
    'name': 'paises',
    'version': '0.1.4',
    'description': '',
    'long_description': 'geo\n',
    'author': 'Tomas',
    'author_email': 'tomasgonz@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



from countries import Countries

def get_group(group_name):
    all_countries = Countries()
    all_countries.load_wb()
    # all_countries.load_fao_code()
    all_countries.load_country_alias()
    
    cs = Countries()

    for c in all_countries:
        if group_name in c.groups:
            cs.append(c)
    
    return cs




